==> release-0.13.zip: docs/docs/serving/samples/README.md <==
Use the following code samples to help you understand the various Knative
Serving resources and how they can be applied across common use cases.
[Learn more about Knative Serving resources](../README.md).

[**See all Knative code samples**](../../samples.md)

| Name                | Description                                                                                                                                                                                                              |                                                                                                                                                                                                                                                                                             Languages                                                                                                                                                                                                                                                                                              |
| ------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| Hello World         | A quick introduction that highlights how to deploy an app using Knative Serving.                                                                                                                                         | [C#](./hello-world/helloworld-csharp/README.md), [Go](./hello-world/helloworld-go/README.md), [Java (Spark)](./hello-world/helloworld-java-spark/README.md), [Java (Spring)](./hello-world/helloworld-java-spring/README.md), [Kotlin](./hello-world/helloworld-kotlin/README.md), [Node.js](./hello-world/helloworld-nodejs/README.md), [PHP](./hello-world/helloworld-php/README.md), [Python](./hello-world/helloworld-python/README.md), [Ruby](./hello-world/helloworld-ruby/README.md), [Scala](./hello-world/helloworld-scala/README.md), [Shell](./hello-world/helloworld-shell/README.md) |
| Cloud Events         | A quick introduction that highlights how to send and receive Cloud Events.                                                                                                                                         | [Go](./cloudevents/cloudevents-go/README.md) |
| Advanced Deployment | Simple blue/green-like application deployment pattern illustrating the process of updating a live application without dropping any traffic.                                                                              |                                                                                                                                                                                                                                                                                 [YAML](./blue-green-deployment.md)                                                                                                                                                                                                                                                                                 |
| Autoscale           | A demonstration of the autoscaling capabilities of Knative.                                                                                                                                                              |                                                                                                                                                                                                                                                                                   [Go](./autoscale-go/README.md)                                                                                                                                                                                                                                                                                   |  |  |  |
| Github Webhook      | A simple webhook handler that demonstrates interacting with Github.                                                                                                                                                      |                                                                                                                                                                                                                                                                                  [Go](./gitwebhook-go/README.md)                                                                                                                                                                                                                                                                                   |
| gRPC                | A simple gRPC server.                                                                                                                                                                                                    |                                                                                                                                                                                                                                                                                   [Go](./grpc-ping-go/README.md)                                                                                                                                                                                                                                                                                   |
| Knative Routing     | An example of mapping multiple Knative services to different paths under a single domain name using the Istio VirtualService concept.                                                                                    |                                                                                                                                                                                                                                                                                [Go](./knative-routing-go/README.md)                                                                                                                                                                                                                                                                                |
| Knative Secrets     | A simple app that demonstrates how to use a Kubernetes secret as a Volume in Knative.                                                                                                                                    |                                                                                                                                                                                                                                                                                    [Go](./secrets-go/README.md)                                                                                                                                                                                                                                                                                    |
| REST API            | A simple Restful service that exposes an endpoint defined by an environment variable described in the Knative Configuration.                                                                                             |                                                                                                                                                                                                                                                                                   [Go](./rest-api-go/README.md)                                                                                                                                                                                                                                                                                    |
| Telemetry           | This sample runs a simple web server that makes calls to other in-cluster services and responds to requests with "Hello World!". The purpose of this sample is to show generating metrics, logs, and distributed traces. |                                                                                                                                                                                                                                                                                   [Go](./telemetry-go/README.md)                                                                                                                                                                                                                                                                                   |
| Traffic Splitting   | This samples builds off the [Creating a RESTful Service](./rest-api-go) sample to illustrate applying a revision, then using that revision for manual traffic splitting.                                                 |                                                                                                                                                                                                                                                                               [YAML](./traffic-splitting/README.md)                                                                                                                                                                                                                                                                                |

==> release-0.18.zip: docs/docs/serving/samples/README.md <==
Use the following code samples to help you understand the various Knative
Serving resources and how they can be applied across common use cases.
[Learn more about Knative Serving resources](../README.md).

[**See all Knative code samples**](../../samples.md)

| Name                | Description                                                                                                                                                                                                              |                                                                                                                                                                                                                                                                                             Languages                                                                                                                                                                                                                                                                                              |
| ------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ | :------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| Hello World         | A quick introduction that highlights how to deploy an app using Knative Serving.                                                                                                                                         | [C#](./hello-world/helloworld-csharp/README.md), [Go](./hello-world/helloworld-go/README.md), [Java (Spark)](./hello-world/helloworld-java-spark/README.md), [Java (Spring)](./hello-world/helloworld-java-spring/README.md), [Kotlin](./hello-world/helloworld-kotlin/README.md), [Node.js](./hello-world/helloworld-nodejs/README.md), [PHP](./hello-world/helloworld-php/README.md), [Python](./hello-world/helloworld-python/README.md), [Ruby](./hello-world/helloworld-ruby/README.md), [Scala](./hello-world/helloworld-scala/README.md), [Shell](./hello-world/helloworld-shell/README.md) |
| Cloud Events        | A quick introduction that highlights how to send and receive Cloud Events.                                                                                                                                               | [C#](./cloudevents/cloudevents-dotnet/README.md), [Go](./cloudevents/cloudevents-go/README.md), [Node.js](./cloudevents/cloudevents-nodejs/README.md), [Rust](./cloudevents/cloudevents-rust/README.md), [Java (Vert.x)](./cloudevents/cloudevents-vertx/README.md)                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| Advanced Deployment | Simple blue/green-like application deployment pattern illustrating the process of updating a live application without dropping any traffic.                                                                              |                                                                                                                                                                                                                                                                                 [YAML](./blue-green-deployment.md)                                                                                                                                                                                                                                                                                 |
| Autoscale           | A demonstration of the autoscaling capabilities of Knative.                                                                                                                                                              |                                                                                                                                                                                                                                                                                   [Go](../autoscaling/autoscale-go/README.md)                                                                                                                                                                                                                                                                                   |
| Github Webhook      | A simple webhook handler that demonstrates interacting with Github.                                                                                                                                                      |                                                                                                                                                                                                                                                                                  [Go](./gitwebhook-go/README.md)                                                                                                                                                                                                                                                                                   |
| gRPC                | A simple gRPC server.                                                                                                                                                                                                    |                                                                                                                                                                                                                                                                                   [Go](./grpc-ping-go/README.md)                                                                                                                                                                                                                                                                                   |
| Knative Routing     | An example of mapping multiple Knative services to different paths under a single domain name using the Istio VirtualService concept.                                                                                    |                                                                                                                                                                                                                                                                                [Go](./knative-routing-go/README.md)                                                                                                                                                                                                                                                                                |
| Knative Secrets     | A simple app that demonstrates how to use a Kubernetes secret as a Volume in Knative.                                                                                                                                    |                                                                                                                                                                                                                                                                                    [Go](./secrets-go/README.md)                                                                                                                                                                                                                                                                                    |
| REST API            | A simple Restful service that exposes an endpoint defined by an environment variable described in the Knative Configuration.                                                                                             |                                                                                                                                                                                                                                                                                   [Go](./rest-api-go/README.md)                                                                                                                                                                                                                                                                                    |
| Traffic Splitting   | This samples builds off the [Creating a RESTful Service](./rest-api-go) sample to illustrate applying a revision, then using that revision for manual traffic splitting.                                                 |                                                                                                                                                                                                                                                                               [YAML](./traffic-splitting/README.md)                                                                                                                                                                                                                                                                                |
